# fasting


[![image](https://img.shields.io/pypi/v/fasting.svg)](https://pypi.python.org/pypi/fasting)
[![image](https://pepy.tech/badge/fasting)](https://pepy.tech/project/fasting)
[![image](https://github.com/jbpauly/fasting/workflows/docs/badge.svg)](https://jbpauly.github.io/fasting)
[![image](https://github.com/jbpauly/fasting/workflows/build/badge.svg)](https://github.com/jbpauly/fasting/actions?query=workflow%3Abuild)
[![image](https://img.shields.io/twitter/follow/j_b_pauly?style=social)](https://twitter.com/j_b_pauly)
[![image](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

**A Python package to  interact with fasting logs from apps like Zero.**


-   Free software: MIT license
-   Documentation: https://jbpauly.github.io/fasting


## Features

-   TODO

## Credits

This package was created with [Cookiecutter](https://github.com/cookiecutter/cookiecutter) and the [giswqs/pypackage](https://github.com/giswqs/pypackage) project template.
